@@ -114,6 +114,8 @@ proc do_faultsim_test {name args} {
   set DEFAULT(-body)          ""
   set DEFAULT(-test)          ""
 
+  fix_testname name
+
   array set O [array get DEFAULT]
   array set O $args
   foreach o [array names O] {
@@ -133,6 +135,7 @@ proc do_faultsim_test {name args} {
   }
 }
 
+
 #-------------------------------------------------------------------------
 # Procedures to save and restore the current file-system state:
 #
@@ -142,29 +145,16 @@ proc do_faultsim_test {name args} {
 #   faultsim_restore_and_reopen
 #   faultsim_delete_and_reopen
 #
-proc faultsim_save {} {
-  foreach f [glob -nocomplain sv_test.db*] { forcedelete $f }
-  foreach f [glob -nocomplain test.db*] {
-    set f2 "sv_$f"
-    file copy -force $f $f2
-  }
+proc faultsim_save {args} { uplevel db_save $args }
+proc faultsim_save_and_close {args} { uplevel db_save_and_close $args }
+proc faultsim_restore {args} { uplevel db_restore $args }
+proc faultsim_restore_and_reopen {args} { 
+  uplevel db_restore_and_reopen $args 
+  sqlite3_extended_result_codes db 1
+  sqlite3_db_config_lookaside db 0 0 0
 }
-proc faultsim_save_and_close {} {
-  faultsim_save
-  catch { db close }
-  return ""
-}
-proc faultsim_restore {} {
-  foreach f [glob -nocomplain test.db*] { forcedelete $f }
-  foreach f2 [glob -nocomplain sv_test.db*] {
-    set f [string range $f2 3 end]
-    file copy -force $f2 $f
-  }
-}
-proc faultsim_restore_and_reopen {{dbfile test.db}} {
-  catch { db close }
-  faultsim_restore
-  sqlite3 db $dbfile
+proc faultsim_delete_and_reopen {args} {
+  uplevel db_delete_and_reopen $args 
   sqlite3_extended_result_codes db 1
   sqlite3_db_config_lookaside db 0 0 0
 }
@@ -174,12 +164,6 @@ proc faultsim_integrity_check {{db db}} {
   if {$ic != "ok"} { error "Integrity check: $ic" }
 }
 
-proc faultsim_delete_and_reopen {{file test.db}} {
-  catch { db close }
-  foreach f [glob -nocomplain test.db*] { file delete -force $f }
-  sqlite3 db $file
-}
-
 
 # The following procs are used as [do_one_faultsim_test] callbacks when 
 # injecting OOM faults into test cases.
@@ -526,7 +510,7 @@ proc do_malloc_test {tn args} {
 # match the expected results passed via parameter $result.
 #
 proc do_select_test {name sql result} {
-  uplevel [list doPassiveTest 0 $name $sql [list 0 $result]]
+  uplevel [list doPassiveTest 0 $name $sql [list 0 [list {*}$result]]]
 }
 
 proc do_restart_select_test {name sql result} {
@@ -540,6 +524,12 @@ proc do_error_test {name sql error} {
 proc doPassiveTest {isRestart name sql catchres} {
   if {![info exists ::DO_MALLOC_TEST]} { set ::DO_MALLOC_TEST 1 }
 
+  if {[info exists ::testprefix] 
+   && [string is integer [string range $name 0 0]]
+  } {
+    set name $::testprefix.$name
+  }
+
   switch $::DO_MALLOC_TEST {
     0 { # No malloc failures.
       do_test $name [list set {} [uplevel [list catchsql $sql]]] $catchres
